@@ -40,7 +40,8 @@ final class LcobucciFactory implements TokenFactoryInterface
     private $jwtLifetime;
 
     /**
-     * @param int|null $jwtLifetime If not null, an "exp" claim is always set to now + $jwtLifetime (in seconds), defaults to "session.cookie_lifetime" or 3600 if "session.cookie_lifetime" is set to 0.
+     * @param non-empty-string $secret
+     * @param int|null         $jwtLifetime If not null, an "exp" claim is always set to now + $jwtLifetime (in seconds), defaults to "session.cookie_lifetime" or 3600 if "session.cookie_lifetime" is set to 0.
      */
     public function __construct(string $secret, string $algorithm = 'hmac.sha256', ?int $jwtLifetime = 0, string $passphrase = '')
     {
@@ -53,7 +54,6 @@ final class LcobucciFactory implements TokenFactoryInterface
         }
 
         $signerClass = self::SIGN_ALGORITHMS[$algorithm];
-        /** @phpstan-ignore-next-line */
         $signer = is_a($signerClass, Signer\Ecdsa::class, true) && method_exists(Signer\Ecdsa::class, 'create') ? $signerClass::create() : new $signerClass();
 
         $this->configurations = Configuration::forSymmetricSigner(
@@ -61,13 +61,13 @@ final class LcobucciFactory implements TokenFactoryInterface
             Key\InMemory::plainText($secret, $passphrase)
         );
 
-        $this->jwtLifetime = 0 === $jwtLifetime ? ((int) ini_get('session.cookie_lifetime') ?: 3600) : $jwtLifetime;
+        $this->jwtLifetime = 0 === $jwtLifetime ? ((int) \ini_get('session.cookie_lifetime') ?: 3600) : $jwtLifetime;
     }
 
     /**
      * {@inheritdoc}
      */
-    public function create(array $subscribe = [], array $publish = [], array $additionalClaims = []): string
+    public function create(?array $subscribe = [], ?array $publish = [], array $additionalClaims = []): string
     {
         $builder = $this->configurations->builder();
 
@@ -75,10 +75,15 @@ final class LcobucciFactory implements TokenFactoryInterface
             $additionalClaims['exp'] = new \DateTimeImmutable("+{$this->jwtLifetime} seconds");
         }
 
-        $additionalClaims['mercure'] = array_merge([
-            'publish' => $publish,
-            'subscribe' => $subscribe,
-        ], $additionalClaims['mercure'] ?? []);
+        $tokens = [];
+        if (null !== $publish) {
+            $tokens['publish'] = (array) $publish;
+        }
+        if (null !== $subscribe) {
+            $tokens['subscribe'] = (array) $subscribe;
+        }
+
+        $additionalClaims['mercure'] = array_merge($tokens, $additionalClaims['mercure'] ?? []);
 
         foreach ($additionalClaims as $name => $value) {
             switch ($name) {
